==> zio-aws-codepipeline_2.13-5.17.154.1-sources.jar: zio/aws/codepipeline/model/ActionTypeSettings.scala <==
package zio.aws.codepipeline.model
import zio.aws.codepipeline.model.primitives.{UrlTemplate, Url}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ActionTypeSettings(
    thirdPartyConfigurationUrl: Option[Url] = None,
    entityUrlTemplate: Option[UrlTemplate] = None,
    executionUrlTemplate: Option[UrlTemplate] = None,
    revisionUrlTemplate: Option[UrlTemplate] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings = {
    import ActionTypeSettings.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings
      .builder()
      .optionallyWith(
        thirdPartyConfigurationUrl.map(value =>
          Url.unwrap(value): java.lang.String
        )
      )(_.thirdPartyConfigurationUrl)
      .optionallyWith(
        entityUrlTemplate.map(value =>
          UrlTemplate.unwrap(value): java.lang.String
        )
      )(_.entityUrlTemplate)
      .optionallyWith(
        executionUrlTemplate.map(value =>
          UrlTemplate.unwrap(value): java.lang.String
        )
      )(_.executionUrlTemplate)
      .optionallyWith(
        revisionUrlTemplate.map(value =>
          UrlTemplate.unwrap(value): java.lang.String
        )
      )(_.revisionUrlTemplate)
      .build()
  }
  def asReadOnly: zio.aws.codepipeline.model.ActionTypeSettings.ReadOnly =
    zio.aws.codepipeline.model.ActionTypeSettings.wrap(buildAwsValue())
}
object ActionTypeSettings {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codepipeline.model.ActionTypeSettings =
      zio.aws.codepipeline.model.ActionTypeSettings(
        thirdPartyConfigurationUrl.map(value => value),
        entityUrlTemplate.map(value => value),
        executionUrlTemplate.map(value => value),
        revisionUrlTemplate.map(value => value)
      )
    def thirdPartyConfigurationUrl: Option[Url]
    def entityUrlTemplate: Option[UrlTemplate]
    def executionUrlTemplate: Option[UrlTemplate]
    def revisionUrlTemplate: Option[UrlTemplate]
    def getThirdPartyConfigurationUrl: ZIO[Any, AwsError, Url] =
      AwsError.unwrapOptionField(
        "thirdPartyConfigurationUrl",
        thirdPartyConfigurationUrl
      )
    def getEntityUrlTemplate: ZIO[Any, AwsError, UrlTemplate] =
      AwsError.unwrapOptionField("entityUrlTemplate", entityUrlTemplate)
    def getExecutionUrlTemplate: ZIO[Any, AwsError, UrlTemplate] =
      AwsError.unwrapOptionField("executionUrlTemplate", executionUrlTemplate)
    def getRevisionUrlTemplate: ZIO[Any, AwsError, UrlTemplate] =
      AwsError.unwrapOptionField("revisionUrlTemplate", revisionUrlTemplate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings
  ) extends zio.aws.codepipeline.model.ActionTypeSettings.ReadOnly {
    override val thirdPartyConfigurationUrl: Option[Url] = scala
      .Option(impl.thirdPartyConfigurationUrl())
      .map(value => zio.aws.codepipeline.model.primitives.Url(value))
    override val entityUrlTemplate: Option[UrlTemplate] = scala
      .Option(impl.entityUrlTemplate())
      .map(value => zio.aws.codepipeline.model.primitives.UrlTemplate(value))
    override val executionUrlTemplate: Option[UrlTemplate] = scala
      .Option(impl.executionUrlTemplate())
      .map(value => zio.aws.codepipeline.model.primitives.UrlTemplate(value))
    override val revisionUrlTemplate: Option[UrlTemplate] = scala
      .Option(impl.revisionUrlTemplate())
      .map(value => zio.aws.codepipeline.model.primitives.UrlTemplate(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings
  ): zio.aws.codepipeline.model.ActionTypeSettings.ReadOnly = new Wrapper(impl)
}

==> zio-aws-codepipeline_2.13-6.20.120.1-sources.jar: zio/aws/codepipeline/model/ActionTypeSettings.scala <==
package zio.aws.codepipeline.model
import zio.aws.codepipeline.model.primitives.{UrlTemplate, Url}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ActionTypeSettings(
    thirdPartyConfigurationUrl: Optional[Url] = Optional.Absent,
    entityUrlTemplate: Optional[UrlTemplate] = Optional.Absent,
    executionUrlTemplate: Optional[UrlTemplate] = Optional.Absent,
    revisionUrlTemplate: Optional[UrlTemplate] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings = {
    import ActionTypeSettings.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings
      .builder()
      .optionallyWith(
        thirdPartyConfigurationUrl.map(value =>
          Url.unwrap(value): java.lang.String
        )
      )(_.thirdPartyConfigurationUrl)
      .optionallyWith(
        entityUrlTemplate.map(value =>
          UrlTemplate.unwrap(value): java.lang.String
        )
      )(_.entityUrlTemplate)
      .optionallyWith(
        executionUrlTemplate.map(value =>
          UrlTemplate.unwrap(value): java.lang.String
        )
      )(_.executionUrlTemplate)
      .optionallyWith(
        revisionUrlTemplate.map(value =>
          UrlTemplate.unwrap(value): java.lang.String
        )
      )(_.revisionUrlTemplate)
      .build()
  }
  def asReadOnly: zio.aws.codepipeline.model.ActionTypeSettings.ReadOnly =
    zio.aws.codepipeline.model.ActionTypeSettings.wrap(buildAwsValue())
}
object ActionTypeSettings {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codepipeline.model.ActionTypeSettings =
      zio.aws.codepipeline.model.ActionTypeSettings(
        thirdPartyConfigurationUrl.map(value => value),
        entityUrlTemplate.map(value => value),
        executionUrlTemplate.map(value => value),
        revisionUrlTemplate.map(value => value)
      )
    def thirdPartyConfigurationUrl: Optional[Url]
    def entityUrlTemplate: Optional[UrlTemplate]
    def executionUrlTemplate: Optional[UrlTemplate]
    def revisionUrlTemplate: Optional[UrlTemplate]
    def getThirdPartyConfigurationUrl: ZIO[Any, AwsError, Url] =
      AwsError.unwrapOptionField(
        "thirdPartyConfigurationUrl",
        thirdPartyConfigurationUrl
      )
    def getEntityUrlTemplate: ZIO[Any, AwsError, UrlTemplate] =
      AwsError.unwrapOptionField("entityUrlTemplate", entityUrlTemplate)
    def getExecutionUrlTemplate: ZIO[Any, AwsError, UrlTemplate] =
      AwsError.unwrapOptionField("executionUrlTemplate", executionUrlTemplate)
    def getRevisionUrlTemplate: ZIO[Any, AwsError, UrlTemplate] =
      AwsError.unwrapOptionField("revisionUrlTemplate", revisionUrlTemplate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings
  ) extends zio.aws.codepipeline.model.ActionTypeSettings.ReadOnly {
    override val thirdPartyConfigurationUrl: Optional[Url] =
      zio.aws.core.internal
        .optionalFromNullable(impl.thirdPartyConfigurationUrl())
        .map(value => zio.aws.codepipeline.model.primitives.Url(value))
    override val entityUrlTemplate: Optional[UrlTemplate] =
      zio.aws.core.internal
        .optionalFromNullable(impl.entityUrlTemplate())
        .map(value => zio.aws.codepipeline.model.primitives.UrlTemplate(value))
    override val executionUrlTemplate: Optional[UrlTemplate] =
      zio.aws.core.internal
        .optionalFromNullable(impl.executionUrlTemplate())
        .map(value => zio.aws.codepipeline.model.primitives.UrlTemplate(value))
    override val revisionUrlTemplate: Optional[UrlTemplate] =
      zio.aws.core.internal
        .optionalFromNullable(impl.revisionUrlTemplate())
        .map(value => zio.aws.codepipeline.model.primitives.UrlTemplate(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codepipeline.model.ActionTypeSettings
  ): zio.aws.codepipeline.model.ActionTypeSettings.ReadOnly = new Wrapper(impl)
}
